from loguru import logger

# default: no log
LOGGER_FLAG = "findit"
logger.disable(LOGGER_FLAG)
